@@ -79,15 +79,15 @@ class Provider(BaseProvider):
     #       appropriate to generate random seconds with.
     if platform.system() == "Windows":
 
-        @property
-        def _rand_seconds(self):
-            return self.generator.random.randint
+        def _rand_seconds(self, start_datetime: int, end_datetime: int) -> float:
+            return self.generator.random.randint(start_datetime, end_datetime)
 
     else:
 
-        @property
-        def _rand_seconds(self):
-            return self.generator.random.uniform
+        def _rand_seconds(self, start_datetime: int, end_datetime: int) -> float:
+            if start_datetime > end_datetime:
+                raise ValueError("empty range for _rand_seconds: start datetime must be before than end datetime")
+            return self.generator.random.uniform(start_datetime, end_datetime)
 
     centuries: ElementsType[str] = [
         "I",
@@ -1826,11 +1826,13 @@ class Provider(BaseProvider):
         Get a timestamp between January 1, 1970 and now, unless passed
         explicit start_datetime or end_datetime values.
 
-        :example: 1061306726
+        On Windows, the decimal part is always 0.
+
+        :example: 1061306726.6
         """
         start_datetime = self._parse_start_datetime(start_datetime)
         end_datetime = self._parse_end_datetime(end_datetime)
-        return self._rand_seconds(start_datetime, end_datetime)
+        return float(self._rand_seconds(start_datetime, end_datetime))
 
     def time_delta(self, end_datetime: Optional[DateParseType] = None) -> timedelta:
         """
